@@ -1,15 +1,16 @@
 from kaggle_environments import make, evaluate
 from kaggle_environments.errors import DeadlineExceeded
 import copy
+import os
 
 env = None
 
 
-def before_each(state=None, configuration=None):
+def before_each(state=None, configuration=None, info={}):
     global env
     steps = [] if state == None else [state]
     env = make("football", steps=steps,
-               configuration=configuration, debug=True)
+               configuration=configuration, info=info, debug=True)
 
 
 def test_to_json():
@@ -103,6 +104,31 @@ def test_single_agent():
         }
     ]
 
+    # Incorrect step from agent 1 (out of range).
+    before_each(configuration={"team_1": 1, "team_2": 0, "scenario_name": "11_vs_11_stochastic"})
+    x = env.reset()
+    assert clear_players_raw(env.step([[100],[]])) == [
+        {
+            "action": [100],
+            "status": "INVALID",
+            "reward": None,
+            'info': {'debug_info': 'Invalid action provided: 100.'},
+            "observation": {
+                "controlled_players": 1,
+                "players_raw": []
+            }
+        },
+        {
+            "action": [],
+            "status": "DONE",
+            "reward": 100,
+            'info': {'debug_info': 'Opponent made invalid move. You win.'},
+            "observation": {
+                "controlled_players": 0,
+                "players_raw": []
+            }
+        }
+    ]
 
 def test_multi_agent():
     before_each(configuration={"team_1": 2, "team_2": 1, "scenario_name": "11_vs_11_stochastic"})
@@ -232,8 +258,13 @@ def test_deadline():
 
 
 def test_render():
-    before_each(configuration={"team_1": 1, "team_2": 1, "scenario_name": "tests.penalty", "save_video": True})
+    video_file = "/tmp/video.webm"
+    before_each(configuration={"team_1": 1, "team_2": 1, "scenario_name": "tests.penalty", "save_video": True},
+        info={"LiveVideoPath": video_file})
     env.step([[0],[0]])
     env.render(mode="human", width=800, height=600)
-    env.step([[0],[0]])
+    output = env.step([[0],[0]])
     env.render(mode="human", width=800, height=600)
+    while output[0]['status'] == 'ACTIVE':
+        output = env.step([[0],[0]])
+    assert os.path.isfile(video_file)
