@@ -74,7 +74,10 @@ class Point(tuple):
         return self.map2(other, operator.add)
 
     def __eq__(self, other: Union[Tuple[int, int], 'Point']) -> bool:
-        return self[0] == other[0] and self[1] == other[1]
+        try:
+            return self[0] == other[0] and self[1] == other[1]
+        except (TypeError, IndexError):
+            return False
 
     def __floordiv__(self, denominator: int) -> 'Point':
         return self.map(lambda x: x // denominator)
@@ -240,6 +243,7 @@ class Configuration(ReadOnlyDict[str, any]):
         """The seed to the random number generator (0 means no seed)."""
         return self["randomSeed"]
 
+
 class ShipAction(Enum):
     NORTH = auto()
     EAST = auto()
